/****************************************************************************
** Meta object code from reading C++ file 'inputmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalk-26.07.90/src/inputmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12InputManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto InputManager::qt_create_metaobjectdata<qt_meta_tag_ZN12InputManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "expressionChanged",
        "",
        "resultChanged",
        "binaryResultChanged",
        "hexResultChanged",
        "cursorPositionChanged",
        "canUndoChanged",
        "canRedoChanged",
        "binaryModeChanged",
        "historyIndexChanged",
        "addHistory",
        "history",
        "idealCursorPosition",
        "position",
        "arrow",
        "append",
        "subexpression",
        "backspace",
        "equal",
        "clear",
        "save",
        "setHistoryIndex",
        "index",
        "fromHistory",
        "result",
        "undo",
        "redo",
        "expression",
        "rawExpression",
        "rawResult",
        "binaryResult",
        "hexResult",
        "moveFromResult",
        "cursorPosition",
        "binaryMode",
        "canUndo",
        "canRedo",
        "historyIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'expressionChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resultChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'binaryResultChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hexResultChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canUndoChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canRedoChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'binaryModeChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'historyIndexChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addHistory'
        QtMocHelpers::SignalData<void(const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'idealCursorPosition'
        QtMocHelpers::MethodData<int(int, int) const>(17, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 18 }, { QMetaType::Int, 19 },
        }}),
        // Method 'idealCursorPosition'
        QtMocHelpers::MethodData<int(int) const>(17, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'backspace'
        QtMocHelpers::MethodData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'equal'
        QtMocHelpers::MethodData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'clear'
        QtMocHelpers::MethodData<void(bool)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(24, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'setHistoryIndex'
        QtMocHelpers::MethodData<void(const int &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Method 'fromHistory'
        QtMocHelpers::MethodData<void(const QString &)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'undo'
        QtMocHelpers::MethodData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'redo'
        QtMocHelpers::MethodData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'expression'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'rawExpression'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'result'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'rawResult'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'binaryResult'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'hexResult'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'moveFromResult'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'cursorPosition'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'binaryMode'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'canUndo'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'canRedo'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'historyIndex'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<InputManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject InputManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12InputManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12InputManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12InputManagerE_t>.metaTypes,
    nullptr
} };

void InputManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->expressionChanged(); break;
        case 1: _t->resultChanged(); break;
        case 2: _t->binaryResultChanged(); break;
        case 3: _t->hexResultChanged(); break;
        case 4: _t->cursorPositionChanged(); break;
        case 5: _t->canUndoChanged(); break;
        case 6: _t->canRedoChanged(); break;
        case 7: _t->binaryModeChanged(); break;
        case 8: _t->historyIndexChanged(); break;
        case 9: _t->addHistory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: { int _r = _t->idealCursorPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->idealCursorPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->backspace(); break;
        case 14: _t->equal(); break;
        case 15: _t->clear((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->clear(); break;
        case 17: _t->setHistoryIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->fromHistory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->undo(); break;
        case 20: _t->redo(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::expressionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::resultChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::binaryResultChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::hexResultChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::cursorPositionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::canUndoChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::canRedoChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::binaryModeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)()>(_a, &InputManager::historyIndexChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputManager::*)(const QString & )>(_a, &InputManager::addHistory, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->expression(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->rawExpression(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->result(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->rawResult(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->binaryResult(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->hexResult(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->moveFromResult(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->getCursorPosition(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->binaryMode(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->canUndo(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->canRedo(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->historyIndex(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 7: _t->setCursorPosition(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setBinaryMode(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setHistoryIndex(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *InputManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12InputManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InputManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void InputManager::expressionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void InputManager::resultChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void InputManager::binaryResultChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void InputManager::hexResultChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void InputManager::cursorPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void InputManager::canUndoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void InputManager::canRedoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void InputManager::binaryModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void InputManager::historyIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void InputManager::addHistory(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
